package com.yiqi.admin.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.app.domain.AppOrgUser;
import com.yiqi.app.service.IAppOrgUserService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 组织客户关系管理Controller
 *
 * @author ruoyi
 * @date 2023-10-25
 */
@Api(tags = "管理后台 - 组织客户关系管理")
@RestController
@RequestMapping(UrlConstants.managerApi + "/app/orgUser")
public class AppOrgUserController extends BaseController {
    @Autowired
    private IAppOrgUserService appOrgUserService;

    /**
     * 查询组织客户关系管理列表
     */
    @PreAuthorize("@ss.hasPermi('app:orgUser:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询组织客户关系管理列表")
    public TableDataInfo list(AppOrgUser appOrgUser) {
        startPage();
        List<AppOrgUser> list = appOrgUserService.selectAppOrgUserList(appOrgUser);
        return getDataTable(list);
    }

    /**
     * 导出组织客户关系管理列表
     */
    @PreAuthorize("@ss.hasPermi('app:orgUser:export')")
    @Log(title = "组织客户关系管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出组织客户关系管理列表")
    public void export(HttpServletResponse response, AppOrgUser appOrgUser) {
        List<AppOrgUser> list = appOrgUserService.selectAppOrgUserList(appOrgUser);
        ExcelUtil<AppOrgUser> util = new ExcelUtil<AppOrgUser>(AppOrgUser. class);
        util.exportExcel(response, list, "组织客户关系管理数据");
    }

    /**
     * 获取组织客户关系管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('app:orgUser:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取组织客户关系管理详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(appOrgUserService.selectAppOrgUserById(id));
    }

    /**
     * 新增组织客户关系管理
     */
    @PreAuthorize("@ss.hasPermi('app:orgUser:add')")
    @Log(title = "组织客户关系管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增组织客户关系管理")
    public AjaxResult add(@RequestBody AppOrgUser appOrgUser) {
        appOrgUser.setCreateById(getUserId());
        appOrgUser.setCreateBy(getUsername());
        return toAjax(appOrgUserService.insertAppOrgUser(appOrgUser));
    }

    /**
     * 修改组织客户关系管理
     */
    @PreAuthorize("@ss.hasPermi('app:orgUser:edit')")
    @Log(title = "组织客户关系管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改组织客户关系管理")
    public AjaxResult edit(@RequestBody AppOrgUser appOrgUser) {
        appOrgUser.setUpdateById(getUserId());
        appOrgUser.setUpdateBy(getUsername());
        return toAjax(appOrgUserService.updateAppOrgUser(appOrgUser));
    }

    /**
     * 删除组织客户关系管理
     */
    @PreAuthorize("@ss.hasPermi('app:orgUser:remove')")
    @Log(title = "组织客户关系管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除组织客户关系管理")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(appOrgUserService.deleteAppOrgUserByIds(ids));
    }

}
