package com.yiqi.admin.controller.core;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yiqi.common.constant.UrlConstants;
import com.yiqi.common.core.domain.R;
import com.yiqi.common.enums.DeleteStatus;
import com.yiqi.common.enums.StatusType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.core.domain.ClothCraft;
import com.yiqi.core.service.IClothCraftService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 衣服工艺Controller
 *
 * @author xiaohei
 * @date 2023-08-20
 */
@Api(tags = "管理后台 - 衣服工艺")
@RestController
@RequestMapping(UrlConstants.managerApi + "/cloth/craft")
public class ClothCraftController extends BaseController {
    @Autowired
    private IClothCraftService clothCraftService;

    @GetMapping("/all")
    @ApiOperation(value = "查询衣服工艺列表")
    public R<List<ClothCraft>> all() {
        return R.ok(clothCraftService.list(new QueryWrapper<ClothCraft>().lambda()
                .eq(ClothCraft::getDelFlag, DeleteStatus.OK.getCode())
                .eq(ClothCraft::getStatus, StatusType.OK.getCode())));
    }

    /**
     * 查询衣服工艺列表
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询衣服工艺列表")
    public TableDataInfo list(ClothCraft clothCraft) {
        startPage();
        List<ClothCraft> list = clothCraftService.selectClothCraftList(clothCraft);
        return getDataTable(list);
    }

    /**
     * 导出衣服工艺列表
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:export')")
    @Log(title = "衣服工艺", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出衣服工艺列表")
    public void export(HttpServletResponse response, ClothCraft clothCraft) {
        List<ClothCraft> list = clothCraftService.selectClothCraftList(clothCraft);
        ExcelUtil<ClothCraft> util = new ExcelUtil<ClothCraft>(ClothCraft. class);
        util.exportExcel(response, list, "衣服工艺数据");
    }

    /**
     * 获取衣服工艺详细信息
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取衣服工艺详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(clothCraftService.selectClothCraftById(id));
    }

    /**
     * 新增衣服工艺
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:add')")
    @Log(title = "衣服工艺", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增衣服工艺")
    public AjaxResult add(@RequestBody ClothCraft clothCraft) {
        clothCraft.setCreateById(getUserId());
        clothCraft.setCreateBy(getUsername());
        return toAjax(clothCraftService.insertClothCraft(clothCraft));
    }

    /**
     * 修改衣服工艺
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:edit')")
    @Log(title = "衣服工艺", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改衣服工艺")
    public AjaxResult edit(@RequestBody ClothCraft clothCraft) {
        clothCraft.setUpdateById(getUserId());
        clothCraft.setUpdateBy(getUsername());
        return toAjax(clothCraftService.updateClothCraft(clothCraft));
    }

    /**
     * 删除衣服工艺
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:remove')")
    @Log(title = "衣服工艺", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除衣服工艺")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(clothCraftService.deleteClothCraftByIds(ids));
    }

    /**
     * 修改衣服工艺状态
     */
    @PreAuthorize("@ss.hasPermi('cloth:craft:edit')")
    @Log(title = "衣服工艺", businessType = BusinessType.UPDATE)
    @PostMapping(value = "updateStatus")
    @ApiOperation(value = "修改衣服工艺状态")
    public AjaxResult updateClothCraftStatus(@RequestBody ClothCraft clothCraft) {
        return toAjax(clothCraftService.updateClothCraftStatus(clothCraft));
    }
}
