package com.yiqi.admin.controller.core;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.core.domain.vo.ClothRewashReasonVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.core.service.IClothRewashReasonService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 衣服重洗原因Controller
 *
 * @author ruoyi
 * @date 2023-09-23
 */
@Api(tags = "管理后台 - 衣服重洗原因")
@RestController
@RequestMapping(UrlConstants.managerApi + "/cloth/reason")
public class ClothRewashReasonController extends BaseController {
    @Autowired
    private IClothRewashReasonService clothRewashReasonService;

    /**
     * 查询衣服重洗原因列表
     */
    @PreAuthorize("@ss.hasPermi('cloth:reason:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询衣服重洗原因列表")
    public TableDataInfo list(ClothRewashReasonVO clothRewashReasonVO) {
        startPage();
        List<ClothRewashReasonVO> list = clothRewashReasonService.selectClothRewashReasonList(clothRewashReasonVO);
        return getDataTable(list);
    }

    /**
     * 导出衣服重洗原因列表
     */
    @PreAuthorize("@ss.hasPermi('cloth:reason:export')")
    @Log(title = "衣服重洗原因", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出衣服重洗原因列表")
    public void export(HttpServletResponse response, ClothRewashReasonVO clothRewashReasonVO) {
        List<ClothRewashReasonVO> list = clothRewashReasonService.selectClothRewashReasonList(clothRewashReasonVO);
        ExcelUtil<ClothRewashReasonVO> util = new ExcelUtil<ClothRewashReasonVO>(ClothRewashReasonVO. class);
        util.exportExcel(response, list, "衣服重洗原因数据");
    }

    /**
     * 获取衣服重洗原因详细信息
     */
    @PreAuthorize("@ss.hasPermi('cloth:reason:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取衣服重洗原因详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(clothRewashReasonService.selectClothRewashReasonById(id));
    }

    /**
     * 新增衣服重洗原因
     */
    @Transactional(rollbackFor = Exception.class)
    @PreAuthorize("@ss.hasPermi('cloth:reason:add')")
    @Log(title = "衣服重洗原因", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增衣服重洗原因")
    public AjaxResult add(@RequestBody ClothRewashReasonVO clothRewashReasonVO) {
        clothRewashReasonVO.setCreateById(getUserId());
        clothRewashReasonVO.setCreateBy(getUsername());
        return toAjax(clothRewashReasonService.insertClothRewashReason(clothRewashReasonVO));
    }

    /**
     * 修改衣服重洗原因
     */
    @Transactional(rollbackFor = Exception.class)
    @PreAuthorize("@ss.hasPermi('cloth:reason:edit')")
    @Log(title = "衣服重洗原因", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改衣服重洗原因")
    public AjaxResult edit(@RequestBody ClothRewashReasonVO clothRewashReasonVO) {
        clothRewashReasonVO.setUpdateById(getUserId());
        clothRewashReasonVO.setUpdateBy(getUsername());
        clothRewashReasonVO.setUpdateTime(DateUtils.getNowDate());
        return toAjax(clothRewashReasonService.updateClothRewashReason(clothRewashReasonVO));
    }

    /**
     * 删除衣服重洗原因
     */
    @PreAuthorize("@ss.hasPermi('cloth:reason:remove')")
    @Log(title = "衣服重洗原因", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除衣服重洗原因")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(clothRewashReasonService.deleteClothRewashReasonByIds(ids));
    }

}
