package com.yiqi.admin.controller.core;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yiqi.common.exception.ServiceException;
import com.yiqi.common.constant.UrlConstants;
import com.yiqi.common.enums.DeleteStatus;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.core.domain.ClothTexture;
import com.yiqi.core.service.IClothTextureService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 衣服质地Controller
 *
 * @author xiaohei
 * @date 2023-08-20
 */
@Api(tags = "管理后台 - 衣服质地")
@RestController
@RequestMapping(UrlConstants.managerApi + "/cloth/texture")
public class ClothTextureController extends BaseController {
    @Autowired
    private IClothTextureService clothTextureService;

    /**
     * 查询衣服质地列表
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询衣服质地列表")
    public TableDataInfo list(ClothTexture clothTexture) {
        startPage();
        List<ClothTexture> list = clothTextureService.selectClothTextureList(clothTexture);
        return getDataTable(list);
    }

    /**
     * 导出衣服质地列表
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:export')")
    @Log(title = "衣服质地", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出衣服质地列表")
    public void export(HttpServletResponse response, ClothTexture clothTexture) {
        List<ClothTexture> list = clothTextureService.selectClothTextureList(clothTexture);
        ExcelUtil<ClothTexture> util = new ExcelUtil<ClothTexture>(ClothTexture. class);
        util.exportExcel(response, list, "衣服质地数据");
    }

    /**
     * 获取衣服质地详细信息
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取衣服质地详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(clothTextureService.selectClothTextureById(id));
    }

    /**
     * 新增衣服质地
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:add')")
    @Log(title = "衣服质地", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增衣服质地")
    public AjaxResult add(@RequestBody ClothTexture clothTexture) {
        if(clothTextureService.count(new QueryWrapper<ClothTexture>().lambda()
                .eq(ClothTexture::getCode,clothTexture.getCode())
                .eq(ClothTexture::getDelFlag, DeleteStatus.OK.getCode())) > 0){
            throw new ServiceException("衣服质地编号已存在");
        }
        clothTexture.setCreateById(getUserId());
        clothTexture.setCreateBy(getUsername());
        return toAjax(clothTextureService.insertClothTexture(clothTexture));
    }

    /**
     * 修改衣服质地
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:edit')")
    @Log(title = "衣服质地", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改衣服质地")
    public AjaxResult edit(@RequestBody ClothTexture clothTexture) {
        if(clothTextureService.count(new QueryWrapper<ClothTexture>().lambda()
                .eq(ClothTexture::getCode,clothTexture.getCode())
                .eq(ClothTexture::getDelFlag, DeleteStatus.OK.getCode())
                .ne(ClothTexture::getId,clothTexture.getId())) > 0){
            throw new ServiceException("衣服质地编号已存在");
        }
        clothTexture.setUpdateById(getUserId());
        clothTexture.setUpdateBy(getUsername());
        return toAjax(clothTextureService.updateClothTexture(clothTexture));
    }

    /**
     * 删除衣服质地
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:remove')")
    @Log(title = "衣服质地", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除衣服质地")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(clothTextureService.deleteClothTextureByIds(ids));
    }

    /**
     * 修改衣服质地状态
     */
    @PreAuthorize("@ss.hasPermi('cloth:texture:edit')")
    @Log(title = "衣服质地", businessType = BusinessType.UPDATE)
    @PostMapping(value = "updateStatus")
    @ApiOperation(value = "修改衣服质地状态")
    public AjaxResult updateClothTextureStatus(@RequestBody ClothTexture clothTexture) {
        return toAjax(clothTextureService.updateClothTextureStatus(clothTexture));
    }
}
