package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderClothCraft;
import com.yiqi.order.service.IOrderClothCraftService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 洗衣订单衣服工艺Controller
 *
 * @author xiaohei
 * @date 2023-10-06
 */
@Api(tags = "管理后台 - 洗衣订单衣服工艺")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/clothCraft")
public class OrderClothCraftController extends BaseController {
    @Autowired
    private IOrderClothCraftService orderClothCraftService;

    /**
     * 查询洗衣订单衣服工艺列表
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询洗衣订单衣服工艺列表")
    public TableDataInfo list(OrderClothCraft orderClothCraft) {
        startPage();
        List<OrderClothCraft> list = orderClothCraftService.selectOrderClothCraftList(orderClothCraft);
        return getDataTable(list);
    }

    /**
     * 导出洗衣订单衣服工艺列表
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:export')")
    @Log(title = "洗衣订单衣服工艺", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出洗衣订单衣服工艺列表")
    public void export(HttpServletResponse response, OrderClothCraft orderClothCraft) {
        List<OrderClothCraft> list = orderClothCraftService.selectOrderClothCraftList(orderClothCraft);
        ExcelUtil<OrderClothCraft> util = new ExcelUtil<OrderClothCraft>(OrderClothCraft. class);
        util.exportExcel(response, list, "洗衣订单衣服工艺数据");
    }

    /**
     * 获取洗衣订单衣服工艺详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取洗衣订单衣服工艺详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderClothCraftService.selectOrderClothCraftById(id));
    }

    /**
     * 新增洗衣订单衣服工艺
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:add')")
    @Log(title = "洗衣订单衣服工艺", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增洗衣订单衣服工艺")
    public AjaxResult add(@RequestBody OrderClothCraft orderClothCraft) {
        orderClothCraft.setCreateById(getUserId());
        orderClothCraft.setCreateBy(getUsername());
        return toAjax(orderClothCraftService.insertOrderClothCraft(orderClothCraft));
    }

    /**
     * 修改洗衣订单衣服工艺
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:edit')")
    @Log(title = "洗衣订单衣服工艺", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改洗衣订单衣服工艺")
    public AjaxResult edit(@RequestBody OrderClothCraft orderClothCraft) {
        orderClothCraft.setUpdateById(getUserId());
        orderClothCraft.setUpdateBy(getUsername());
        return toAjax(orderClothCraftService.updateOrderClothCraft(orderClothCraft));
    }

    /**
     * 删除洗衣订单衣服工艺
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:remove')")
    @Log(title = "洗衣订单衣服工艺", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除洗衣订单衣服工艺")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderClothCraftService.deleteOrderClothCraftByIds(ids));
    }

}
