package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderClothItemCouponRelation;
import com.yiqi.order.service.IOrderClothItemCouponRelationService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 洗衣订单衣服优惠情况Controller
 *
 * @author xiaohei
 * @date 2023-11-07
 */
@Api(tags = "管理后台 - 洗衣订单衣服优惠情况")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/orderClothItemCouponRelation")
public class OrderClothItemCouponRelationController extends BaseController {
    @Autowired
    private IOrderClothItemCouponRelationService orderClothItemCouponRelationService;

    /**
     * 查询洗衣订单衣服优惠情况列表
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothItemCouponRelation:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询洗衣订单衣服优惠情况列表")
    public TableDataInfo list(OrderClothItemCouponRelation orderClothItemCouponRelation) {
        startPage();
        List<OrderClothItemCouponRelation> list = orderClothItemCouponRelationService.selectOrderClothItemCouponRelationList(orderClothItemCouponRelation);
        return getDataTable(list);
    }

    /**
     * 导出洗衣订单衣服优惠情况列表
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothItemCouponRelation:export')")
    @Log(title = "洗衣订单衣服优惠情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出洗衣订单衣服优惠情况列表")
    public void export(HttpServletResponse response, OrderClothItemCouponRelation orderClothItemCouponRelation) {
        List<OrderClothItemCouponRelation> list = orderClothItemCouponRelationService.selectOrderClothItemCouponRelationList(orderClothItemCouponRelation);
        ExcelUtil<OrderClothItemCouponRelation> util = new ExcelUtil<OrderClothItemCouponRelation>(OrderClothItemCouponRelation. class);
        util.exportExcel(response, list, "洗衣订单衣服优惠情况数据");
    }

    /**
     * 获取洗衣订单衣服优惠情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothItemCouponRelation:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取洗衣订单衣服优惠情况详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderClothItemCouponRelationService.selectOrderClothItemCouponRelationById(id));
    }

    /**
     * 新增洗衣订单衣服优惠情况
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothItemCouponRelation:add')")
    @Log(title = "洗衣订单衣服优惠情况", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增洗衣订单衣服优惠情况")
    public AjaxResult add(@RequestBody OrderClothItemCouponRelation orderClothItemCouponRelation) {
        orderClothItemCouponRelation.setCreateById(getUserId());
        orderClothItemCouponRelation.setCreateBy(getUsername());
        return toAjax(orderClothItemCouponRelationService.insertOrderClothItemCouponRelation(orderClothItemCouponRelation));
    }

    /**
     * 修改洗衣订单衣服优惠情况
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothItemCouponRelation:edit')")
    @Log(title = "洗衣订单衣服优惠情况", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改洗衣订单衣服优惠情况")
    public AjaxResult edit(@RequestBody OrderClothItemCouponRelation orderClothItemCouponRelation) {
        orderClothItemCouponRelation.setUpdateById(getUserId());
        orderClothItemCouponRelation.setUpdateBy(getUsername());
        return toAjax(orderClothItemCouponRelationService.updateOrderClothItemCouponRelation(orderClothItemCouponRelation));
    }

    /**
     * 删除洗衣订单衣服优惠情况
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothItemCouponRelation:remove')")
    @Log(title = "洗衣订单衣服优惠情况", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除洗衣订单衣服优惠情况")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderClothItemCouponRelationService.deleteOrderClothItemCouponRelationByIds(ids));
    }

}
