package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderClothType;
import com.yiqi.order.service.IOrderClothTypeService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 洗衣订单衣服类型Controller
 *
 * @author xiaohei
 * @date 2023-10-06
 */
@Api(tags = "管理后台 - 洗衣订单衣服类型")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/clothType")
public class OrderClothTypeController extends BaseController {
    @Autowired
    private IOrderClothTypeService orderClothTypeService;

    /**
     * 查询洗衣订单衣服类型列表
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询洗衣订单衣服类型列表")
    public TableDataInfo list(OrderClothType orderClothType) {
        startPage();
        List<OrderClothType> list = orderClothTypeService.selectOrderClothTypeList(orderClothType);
        return getDataTable(list);
    }

    /**
     * 导出洗衣订单衣服类型列表
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:export')")
    @Log(title = "洗衣订单衣服类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出洗衣订单衣服类型列表")
    public void export(HttpServletResponse response, OrderClothType orderClothType) {
        List<OrderClothType> list = orderClothTypeService.selectOrderClothTypeList(orderClothType);
        ExcelUtil<OrderClothType> util = new ExcelUtil<OrderClothType>(OrderClothType. class);
        util.exportExcel(response, list, "洗衣订单衣服类型数据");
    }

    /**
     * 获取洗衣订单衣服类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取洗衣订单衣服类型详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderClothTypeService.selectOrderClothTypeById(id));
    }

    /**
     * 新增洗衣订单衣服类型
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:add')")
    @Log(title = "洗衣订单衣服类型", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增洗衣订单衣服类型")
    public AjaxResult add(@RequestBody OrderClothType orderClothType) {
        orderClothType.setCreateById(getUserId());
        orderClothType.setCreateBy(getUsername());
        return toAjax(orderClothTypeService.insertOrderClothType(orderClothType));
    }

    /**
     * 修改洗衣订单衣服类型
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:edit')")
    @Log(title = "洗衣订单衣服类型", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改洗衣订单衣服类型")
    public AjaxResult edit(@RequestBody OrderClothType orderClothType) {
        orderClothType.setUpdateById(getUserId());
        orderClothType.setUpdateBy(getUsername());
        return toAjax(orderClothTypeService.updateOrderClothType(orderClothType));
    }

    /**
     * 删除洗衣订单衣服类型
     */
    @PreAuthorize("@ss.hasPermi('order:cloth:remove')")
    @Log(title = "洗衣订单衣服类型", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除洗衣订单衣服类型")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderClothTypeService.deleteOrderClothTypeByIds(ids));
    }

}
