package com.yiqi.activity.domain;

import java.math.BigDecimal;
import java.util.Date;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yiqi.common.annotation.Excel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.yiqi.common.core.domain.BaseEntity;
import lombok.Data;

/**
 * 活动明细对象 activity_info
 *
 * @author xiaohei
 * @date 2023-09-08
 */
@ApiModel("活动明细")
@TableName("activity_info")
@Data
public class ActivityInfo extends BaseEntity
{
    private static final long serialVersionUID=1L;

    /** 主键ID */
    @ApiModelProperty("主键ID")
    @TableId(type = IdType.AUTO)
    private Long id;

    /** 标题 */
    @Excel(name = "标题")
    @ApiModelProperty("标题")
    private String title;

    /** 描述 */
    @Excel(name = "描述")
    @ApiModelProperty("描述")
    private String description;

    /** 宣传图片 */
    @Excel(name = "宣传图片")
    @ApiModelProperty("宣传图片")
    private String imgUrl;

    /** 内容 */
    @Excel(name = "内容")
    @ApiModelProperty("内容")
    private String content;

    /** 门店数量 */
    @Excel(name = "门店数量")
    @ApiModelProperty("门店数量")
    @TableField(exist = false)
    private Long storeNum;

    @Excel(name = "适用衣服")
    @ApiModelProperty("适用衣服 1：全部衣服 2：指定衣服")
    private String clothScope;

    @ApiModelProperty("适用用户范围（0=全部用户，1=会员用户）")
    private String userScope;

    @ApiModelProperty("支付范围（0=全部,1=现金,2=余额）")
    private String payScope;

    /** 折扣 */
    @Excel(name = "折扣")
    @ApiModelProperty("折扣")
    private BigDecimal discount;

    /** 开始时间 */
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    @Excel(name = "开始时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("开始时间")
    private Date startDate;

    /** 结束时间 */
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    @Excel(name = "结束时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("结束时间")
    private Date endDate;

    /** 活动类型（0=充值多送,1=注册送券,2=全场折扣,3=指定折扣） */
    @Excel(name = "活动类型", readConverterExp = "0==充值多送,1=注册送券,2=全场折扣,3=指定折扣")
    @ApiModelProperty("活动类型（0=充值多送,1=注册送券,2=全场折扣,3=指定折扣）")
    private String activityType;

    /** 状态（0=正常,1=停用） */
    @Excel(name = "状态", readConverterExp = "0==正常,1=停用")
    @ApiModelProperty("状态（0=正常,1=停用）")
    private String status;

    /** 删除状态（0=正常,2=删除） */
    @ApiModelProperty("删除状态（0=正常,2=删除）")
    private String delFlag;
}
