package com.yiqi.activity.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.activity.domain.ActivityCouponInfo;
import com.yiqi.activity.domain.dto.ActivityAppCouponItemQueryDTO;
import com.yiqi.activity.domain.dto.ActivityCouponInfoDTO;
import com.yiqi.activity.domain.vo.ActivityAppCouponItemVO;
import com.yiqi.activity.domain.vo.ActivityCouponInfoVO;
import com.yiqi.app.domain.AppCouponType;

/**
 * 注册送券活动Service接口
 *
 * @author xiaohei
 * @date 2023-09-08
 */
public interface IActivityCouponInfoService extends IService<ActivityCouponInfo> {
    /**
     * 查询注册送券活动
     *
     * @param id 注册送券活动主键
     * @return 注册送券活动
     */
    public ActivityCouponInfoVO selectActivityCouponInfoById(Long id);


    /**
     * 查询活动优惠券信息，通过发放优惠劵
     *
     * @param activityId 活动主键
     * @return 注册送券活动
     */
    public ActivityCouponInfoVO selectActivityCouponInfoBySendCoupon(Long activityId, Long couponTypeId);

    /**
     * 查询注册送券活动列表
     *
     * @param activityCouponInfoDTO 注册送券活动
     * @return 注册送券活动集合
     */
     public List<ActivityCouponInfoVO> selectActivityCouponInfoList(ActivityCouponInfoDTO activityCouponInfoDTO);

    /**
     * 新增注册送券活动
     *
     * @param activityCouponInfoDTO 注册送券活动
     * @return 结果
     */
    public int insertActivityCouponInfo(ActivityCouponInfoDTO activityCouponInfoDTO);

    /**
     * 修改注册送券活动
     *
     * @param activityCouponInfoDTO 注册送券活动
     * @return 结果
     */
    public int updateActivityCouponInfo(ActivityCouponInfoDTO activityCouponInfoDTO);

    /**
     * 批量删除注册送券活动
     *
     * @param ids 需要删除的注册送券活动主键集合
     * @return 结果
     */
    public int deleteActivityCouponInfoByIds(Long[] ids,String activityType);

    /**
     * 删除注册送券活动信息
     *
     * @param id 注册送券活动主键
     * @return 结果
     */
    public int deleteActivityCouponInfoById(Long id,String activityType);


    List<AppCouponType> selectActivityCouponItemList(ActivityAppCouponItemQueryDTO activityAppCouponItemQueryDTO);

    int countActivityCouponItemList(ActivityAppCouponItemQueryDTO activityAppCouponItemQueryDTO);
}
