package com.yiqi.app.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.app.domain.AppUserBillMstr;
import com.yiqi.common.core.domain.R;
import com.yiqi.order.domain.dto.RefundBaseDTO;
import com.yiqi.recharge.domain.dto.BillMstrOrderDTO;
import com.yiqi.recharge.domain.dto.ConsumeOrderDTO;

/**
 * 用户账单Service接口
 *
 * @author xiaohei
 * @date 2023-11-02
 */
public interface IAppUserBillMstrService extends IService<AppUserBillMstr> {

    public AppUserBillMstr buildBillMstr(ConsumeOrderDTO consumeOrderDTO);

    /**
     * 添加消费记录
     * @return
     */
    public R consumeRecord(ConsumeOrderDTO consumeOrderDTO);

    /**
     * 添加退款记录
     * @param consumeOrderDTO
     * @param refundBaseDTO
     * @return
     */
    public R<String> refundRecord(ConsumeOrderDTO consumeOrderDTO, RefundBaseDTO refundBaseDTO);

    /**
     * 添加账单订单
     * @param billMstrOrderDTO
     */
    void saveBillMstrOrder(BillMstrOrderDTO billMstrOrderDTO);

    /**
     * 添加账单订单
     * @param billMstrOrderDTO
     */
    void saveRefundBillMstrOrder(BillMstrOrderDTO billMstrOrderDTO);

    //<editor-folder desc="基础函数">
    /**
     * 查询用户账单
     *
     * @param id 用户账单主键
     * @return 用户账单
     */
    public AppUserBillMstr selectAppUserBillMstrById(Long id);

    /**
     * 查询用户账单列表
     *
     * @param appUserBillMstr 用户账单
     * @return 用户账单集合
     */
    public List<AppUserBillMstr> selectAppUserBillMstrList(AppUserBillMstr appUserBillMstr);

    /**
     * 新增用户账单
     *
     * @param appUserBillMstr 用户账单
     * @return 结果
     */
    public int insertAppUserBillMstr(AppUserBillMstr appUserBillMstr);

    /**
     * 修改用户账单
     *
     * @param appUserBillMstr 用户账单
     * @return 结果
     */
    public int updateAppUserBillMstr(AppUserBillMstr appUserBillMstr);

    /**
     * 批量删除用户账单
     *
     * @param ids 需要删除的用户账单主键集合
     * @return 结果
     */
    public int deleteAppUserBillMstrByIds(Long[] ids);

    /**
     * 删除用户账单信息
     *
     * @param id 用户账单主键
     * @return 结果
     */
    public int deleteAppUserBillMstrById(Long id);



    //</editor-folder>


}
