package com.yiqi.app.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.app.domain.AppUser;
import com.yiqi.app.domain.dto.weapp.WeAppWxLoginDTO;
import com.yiqi.app.domain.vo.AppUserInfoVO;
import com.yiqi.app.domain.vo.AppUserLoginVO;
import com.yiqi.common.core.domain.R;

import java.util.List;

/**
 * 用户Service接口
 *
 * @author ruoyi
 * @date 2023-09-27
 */
public interface IAppUserService extends IService<AppUser> {

    public R<AppUserLoginVO> wxLogin(WeAppWxLoginDTO weAppWxLoginDTO) throws Exception;

    AppUserInfoVO getAppUserInfoById(Long appUserId);

    List<AppUserInfoVO> getAppUserInfoByIds(List<Long> appUserIds);

    /**
     * 查询用户
     *
     * @param id 用户主键
     * @return 用户
     */
    public AppUser selectAppUserById(Long id);

    /**
     * 查询用户列表
     *
     * @param appUser 用户
     * @return 用户集合
     */
    public List<AppUser> selectAppUserList(AppUser appUser);

    /**
     * 新增用户
     *
     * @param appUser 用户
     * @return 结果
     */
    public int insertAppUser(AppUser appUser);

    /**
     * 修改用户
     *
     * @param appUser 用户
     * @return 结果
     */
    public int updateAppUser(AppUser appUser);

    /**
     * 批量删除用户
     *
     * @param ids 需要删除的用户主键集合
     * @return 结果
     */
    public int deleteAppUserByIds(Long[] ids);

    /**
     * 删除用户信息
     *
     * @param id 用户主键
     * @return 结果
     */
    public int deleteAppUserById(Long id);


    /**
     * 修改用户状态
     *
     * @param appUser 用户
     * @return 结果
     */
    public int updateAppUserStatus(AppUser appUser);

    /**
     * 校验用户是否为会员
     *
     * @param appUserId
     * @return
     */
    Boolean checkUserIsMember(Long appUserId);

    /**
     * 校验用户是否为新用户
     *
     * @param appUserId
     * @return
     */
    Boolean checkUserIsNewUser(Long appUserId);

}
