package com.yiqi.core.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.core.domain.GoodsSkuSpec;
import com.yiqi.core.domain.GoodsSkuStore;
import com.yiqi.core.domain.GoodsStore;
import com.yiqi.order.domain.OrderGoods;
import com.yiqi.order.domain.OrderGoodsSku;
import com.yiqi.order.domain.OrderPurchaseGoods;
import com.yiqi.order.domain.OrderPurchaseGoodsSku;
import com.yiqi.system.domain.ManageFactory;
import com.yiqi.system.domain.SysStore;

import java.util.List;

/**
 * 商品物料门店关联Service接口
 *
 * @author ruoyi
 * @date 2023-09-05
 */
public interface IGoodsSkuStoreService extends IService<GoodsSkuStore> {
    /**
     * 查询商品物料门店关联
     *
     * @param id 商品物料门店关联主键
     * @return 商品物料门店关联
     */
    public GoodsSkuStore selectGoodsSkuStoreById(Long id);

    /**
     * 查询商品物料门店关联列表
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 商品物料门店关联集合
     */
    public List<GoodsSkuStore> selectGoodsSkuStoreList(GoodsSkuStore goodsSkuStore);

    /**
     * 新增商品物料门店关联
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 结果
     */
    public int insertGoodsSkuStore(GoodsSkuStore goodsSkuStore);

    /**
     * 修改商品物料门店关联
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 结果
     */
    public int updateGoodsSkuStore(GoodsSkuStore goodsSkuStore);

    /**
     * 批量删除商品物料门店关联
     *
     * @param ids 需要删除的商品物料门店关联主键集合
     * @return 结果
     */
    public int deleteGoodsSkuStoreByIds(Long[] ids);

    /**
     * 删除商品物料门店关联信息
     *
     * @param id 商品物料门店关联主键
     * @return 结果
     */
    public int deleteGoodsSkuStoreById(Long id);


    /**
     * 修改商品物料门店关联状态
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 结果
     */
    public int updateGoodsSkuStoreStatus(GoodsSkuStore goodsSkuStore);


    /**
     * 查询商品物料门店 通过物料id
     *
     * @param skuId 商品物料id
     * @return 商品规格集合
     */
    public List<GoodsSkuStore> getSkuStoreListBySkuId(Long skuId);


    /**
     * 查询商品物料门店 通过物料id
     *
     * @param skuId 商品物料id
     * @return 商品规格集合
     */
    public GoodsSkuStore getSkuStoreBySkuIdAndOrgId(Long skuId, String sourceType, Long orgId);

    /**
     * 批量新增物料工厂关系
     *
     * @param goodsSkuStore 商品物料门店
     * @return 结果
     */
    public int insertSkuToAllFactory(GoodsSkuStore goodsSkuStore);

    /**
     * 批量新增物料门店关系
     *
     * @param goodsSkuStore 商品物料门店
     * @return 结果
     */
    public int insertSkuToAllStore(GoodsSkuStore goodsSkuStore);

    /**
     * 批量新增工厂和全部商品物料关系
     *
     * @param manageFactory 工厂实例
     * @return 结果
     */
    public int insertFactoryToAllSku(ManageFactory manageFactory);

    /**
     * 批量新增门店和全部商品物料关系
     *
     * @param sysStore 门店实例
     * @return 结果
     */
    public int insertStoreToAllSku(SysStore sysStore);


    /**
     * 批量增加商品物料库存
     *
     * @param goodsSkuStoreList 增加商品物料库存
     * @return 结果
     */
    public int addGoodsSkuStockByOrderItems(List<GoodsSkuStore> goodsSkuStoreList);

    /**
     * 减去商品物料库存
     *
     * @param goodsSkuStoreList 减去商品物料库存
     * @return 结果
     */
    public int minusGoodsSkuStockByOrder(List<GoodsSkuStore> goodsSkuStoreList);

    /**
     *  组装进货加库存的VO
     * @param orderPurchaseGoodsSkus
     * @return
     */
    List<GoodsSkuStore> buildGoodsSkuStockVOByPurchase2AddStock(List<OrderPurchaseGoodsSku> orderPurchaseGoodsSkus, OrderPurchaseGoods orderPurchaseGoods);
    /**
     *  组装出货减库存的VO
     * @param orderPurchaseGoodsSkus
     * @return
     */
    List<GoodsSkuStore> buildGoodsSkuStockVOByPurchase2MinusStock(List<OrderPurchaseGoodsSku> orderPurchaseGoodsSkus, OrderPurchaseGoods orderPurchaseGoods);

    /**
     * 商品-零售 组装加/减库存的VO
     * @param orderGoodsSkus
     * @return
     */
    List<GoodsSkuStore> buildGoodsSkuStockVOByRetailOrder(List<OrderGoodsSku> orderGoodsSkus, OrderGoods orderGoods);
}
