package com.yiqi.order.domain;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiqi.common.annotation.Excel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;

/**
 * 第三方支付记录对象 order_pay_info
 *
 * @author douya
 * @date 2024-08-21
 */
@ApiModel("第三方支付记录")
@TableName("order_pay_info")
@Data
public class OrderPayInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键ID
     */
    @ApiModelProperty("主键ID")
    @TableId(type = IdType.AUTO)
    @JsonSerialize(using = ToStringSerializer.class)
    private Long id;

    @ApiModelProperty("门店ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long storeId;

    /**
     * 订单编号
     */
    @Excel(name = "订单编号")
    @ApiModelProperty("订单编号")
    private String orderNo;

    /**
     * 支付订单编号
     */
    @Excel(name = "支付请求编号")
    @ApiModelProperty("支付请求编号")
    private String requestNo;

    /**
     * 支付金额
     */
    @Excel(name = "支付金额")
    @ApiModelProperty("支付金额")
    private BigDecimal payAmount;

    /**
     * 支付商户号
     */
    @Excel(name = "支付商户号")
    @ApiModelProperty("支付商户号")
    private String payMno;

    /**
     * 支付方式（0=微信，1=支付宝）
     */
    @Excel(name = "支付方式", readConverterExp = "0==微信，1=支付宝")
    @ApiModelProperty("支付方式（0=微信，1=支付宝）")
    private String payType;

    /**
     * 支付状态（0=待支付，1=已支付，-1：已失败）
     */
    @Excel(name = "支付状态", readConverterExp = "0==待支付，1=已支付，-1：已失败")
    @ApiModelProperty("支付状态（0=待支付，1=已支付，-1：已失败）")
    private String payStatus;

    /**
     * 返回消息
     */
    @Excel(name = "返回消息")
    @ApiModelProperty("返回消息")
    private String msg;


    /**
     * 创建时间
     */
    @ApiModelProperty("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date createTime;
}
