package com.yiqi.order.domain.vo;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiqi.common.annotation.Excel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

@ApiModel("订单商品退款列表对象")
@Data
public class GoodsOrderRefundQueryVO {
    /**
     * 主键ID
     */
    @ApiModelProperty("主键ID")
    @TableId(type = IdType.AUTO)
    @JsonSerialize(using = ToStringSerializer.class)
    private Long id;

    /**
     * 订单编号
     */
    @Excel(name = "订单编号")
    @ApiModelProperty("订单编号")
    private String orderNo;

    /**
     * 来源类型
     */
    @Excel(name = "来源类型")
    @ApiModelProperty("来源类型")
    private String sourceType;

    /**
     * 组织ID
     */
    @Excel(name = "组织ID")
    @ApiModelProperty("组织ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long orgId;

    /**
     * 客户ID
     */
    @Excel(name = "客户ID")
    @ApiModelProperty("客户ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long appUserId;

    @ApiModelProperty("客户地址id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long appUserAddressId;

    /**
     * 商品类别
     */
    @Excel(name = "商品类别")
    @ApiModelProperty("商品类别")
    private String goodsType;

    /**
     * 商品订单类型
     */
    @Excel(name = "商品订单类型")
    @ApiModelProperty("商品订单类型")
    private String goodsOrderType;


    /**
     * 订单总价
     */
    @Excel(name = "订单总价")
    @ApiModelProperty("订单总价")
    private BigDecimal totalPrice;

    /**
     * 抵扣金额
     */
    @Excel(name = "抵扣金额")
    @ApiModelProperty("抵扣金额")
    private BigDecimal deductAmount;

    /**
     * 抵扣积分
     */
    @Excel(name = "抵扣积分")
    @ApiModelProperty("抵扣积分")
    private Integer deductPoint;

    /**
     * 支付金额
     */
    @Excel(name = "支付金额")
    @ApiModelProperty("支付金额")
    private BigDecimal payAmount;

    /**
     * 配送方式（0=到店自取，1=快递）
     */
    @Excel(name = "配送方式", readConverterExp = "0=到店自取,1=快递")
    @ApiModelProperty("配送方式（0=到店自取，1=快递）")
    private String deliveryWay;

    /**
     * 快递公司
     */
    @Excel(name = "快递公司")
    @ApiModelProperty("快递公司")
    private String deliveryCompany;

    /**
     * 快递单号
     */
    @Excel(name = "快递单号")
    @ApiModelProperty("快递单号")
    private String deliveryNo;

    /**
     * 订单状态（0待支付，1支付待确认，2已支付、待配送，3配送中，4已到货，5确认收货，-1取消订单）
     */
    @Excel(name = "订单状态", readConverterExp = "0=待支付,1=支付待确认,2=已支付、待配送,3=配送中,4=已到货,5=确认收货,-1=取消订单")
    @ApiModelProperty("订单状态（0待支付，1支付待确认，2已支付、待配送，3配送中，4已到货，5确认收货，-1取消订单）")
    private String orderStatus;

    @ApiModelProperty("预约时间")
    @Excel(name = "预约时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm",timezone = "GMT+8")
    private Date appointmentTime;

    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date createTime;

    /**
     * 支付时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @Excel(name = "支付时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("支付时间")
    private Date payTime;

    /**
     * 发货时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @Excel(name = "发货时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("发货时间")
    private Date sendTime;

    /**
     * 确认收货时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @Excel(name = "确认收货时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("确认收货时间")
    private Date finishTime;

    /**
     * 退款状态（0=正常，1=退款申请中，2=退款同意，3=退款拒绝，4=退款取消）
     */
    @Excel(name = "退款状态", readConverterExp = "0=正常,1=退款申请中,2=退款同意,3=退款拒绝,4=退款取消")
    @ApiModelProperty("退款状态（0=正常，1=退款申请中，2=退款同意，3=退款拒绝，4=退款取消）")
    private String refundStatus;

    /**
     * 退款原因
     */
    @Excel(name = "退款原因")
    @ApiModelProperty("退款原因")
    private String refundReason;

    /**
     * 退款时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @Excel(name = "退款时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("退款时间")
    private Date refundTime;

    /**
     * 退款金额
     */
    @Excel(name = "退款金额")
    @ApiModelProperty("退款金额")
    private BigDecimal refundAmount;

    /**
     * 支付方式（0=微信，1=支付宝，2=现金,3=余额）
     */
    @Excel(name = "支付方式", readConverterExp = "0=微信,1=支付宝,2=现金,3=余额")
    @ApiModelProperty("支付方式（0=微信，1=支付宝，2=现金,3=余额）")
    private String payType;


    @ApiModelProperty("支付宝/微信支付订单号")
    private String outTradeOrderNo;

    @Excel(name = "省")
    @ApiModelProperty("省")
    private String province;

    @Excel(name = "城市")
    @ApiModelProperty("城市")
    private String city;

    @Excel(name = "区域")
    @ApiModelProperty("区域")
    private String area;

    @Excel(name = "地址")
    @ApiModelProperty("地址")
    private String address;

    @Excel(name = "门牌号")
    @ApiModelProperty("门牌号")
    private String addressDetail;

    @Excel(name = "联系人姓名")
    @ApiModelProperty("联系人姓名")
    private String contactName;

    @Excel(name = "联系人手机号")
    @ApiModelProperty("联系人手机号")
    private String contactPhone;

    /** 手机号 */
    @Excel(name = "手机号")
    @ApiModelProperty("手机号")
    private String phoneNumber;

    /** 昵称 */
    @Excel(name = "昵称")
    @ApiModelProperty("昵称")
    private String nickName;

    /** 真实姓名 */
    @Excel(name = "真实姓名")
    @ApiModelProperty("真实姓名")
    private String realName;


}
