package com.yiqi.order.domain.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiqi.common.annotation.Excel;
import com.yiqi.common.core.domain.BaseEntity;
import com.yiqi.system.domain.SysOrg;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 洗衣订单对象 order_cloth
 *
 * @author xiaohei
 * @date 2023-10-17
 */
@Data
public class OrderClothRecordVO extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 订单编号
     */
    @Excel(name = "订单编号")
    @ApiModelProperty("订单编号")
    private String orderNo;

    /**
     * 门店ID
     */
    @ApiModelProperty("门店ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long storeId;


    /** 门店名称 */
    @ApiModelProperty("门店名称")
    private String storeName;

    /**
     * 来源类型
     */
    @Excel(name = "来源类型")
    @ApiModelProperty("来源类型")
    private String sourceType;

    /**
     * 工厂ID
     */
    @Excel(name = "工厂ID")
    @ApiModelProperty("工厂ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long factoryId;

    /**
     * 客户ID
     */
    @Excel(name = "客户ID")
    @ApiModelProperty("客户ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long appUserId;

    /** 真实姓名 */
    @Excel(name = "真实姓名")
    @ApiModelProperty("真实姓名")
    private String realName;


    /**
     * 完成时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    @ApiModelProperty("完成时间")
    private Date finishTime;

    /**
     * 取货时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    @ApiModelProperty("取货时间")
    private Date pickUpTime;

    /**
     * 送店时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    @ApiModelProperty("送店时间")
    private Date sendToStoreTime;

    /**
     * 送衣时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    @Excel(name = "送衣时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("送衣时间")
    private Date sendToUserTime;

    /**
     * 送衣人
     */
    @Excel(name = "送衣人")
    @ApiModelProperty("送衣人")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long sendClothAppUserId;


    /**
     * 送衣方式（0=到店，1=上门）
     */
    @Excel(name = "送衣方式", readConverterExp = "0==到店，1=上门")
    @ApiModelProperty("送衣方式（0=到店，1=上门）")
    private String sendClothWay;

}
