package com.yiqi.order.domain.vo.weapp;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiqi.activity.domain.ActivityCouponInfo;
import com.yiqi.activity.domain.vo.ActivityCouponInfoVO;
import com.yiqi.common.annotation.Excel;
import com.yiqi.order.domain.OrderActivityItem;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

@Data
public class AppActivityOrderInfoQueryVO {
    /**
     * 主键ID
     */
    @ApiModelProperty("主键ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long id;

    /** 活动id */
    @Excel(name = "活动id")
    @ApiModelProperty("活动id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long activityId;

    /**
     * 订单编号
     */
    @Excel(name = "订单编号")
    @ApiModelProperty("订单编号")
    private String orderNo;

    @ApiModelProperty("客户ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long appUserId;

    /**
     * 支付时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @Excel(name = "支付时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("支付时间")
    private Date payTime;

    /**
     * 支付金额
     */
    @Excel(name = "支付金额")
    @ApiModelProperty("支付金额")
    private BigDecimal payAmount;

    /**
     * 支付方式（0=微信，1=支付宝，2=现金）
     */
    @Excel(name = "支付方式", readConverterExp = "0==微信，1=支付宝")
    @ApiModelProperty("支付方式（0=微信，1=支付宝）")
    private String payType;

    /**
     * 下单渠道（APP=APP，WXAPP=小程序）
     */
    @Excel(name = "下单渠道", readConverterExp = "A=PP=APP，WXAPP=小程序")
    @ApiModelProperty("下单渠道（APP=APP，WXAPP=小程序）")
    private String orderSource;

    /**
     * 支付宝/微信支付订单号
     */
    @Excel(name = "支付宝/微信支付订单号")
    @ApiModelProperty("支付宝/微信支付订单号")
    private String outTradeOrderNo;

    /**
     * 订单状态（0=待付款，1=已付款、待确认，2=已付款，3=已完成，4=退款申请中，5=退款失败，6=已退款，100=已取消）
     */
    @Excel(name = "订单状态", readConverterExp = "0==待付款，1=已付款、待确认，2=已付款，3=已完成，4=退款申请中，5=退款失败，6=已退款，100=已取消")
    @ApiModelProperty("订单状态（0=待付款，1=已付款、待确认，2=已付款，3=已完成，4=退款申请中，5=退款失败，6=已退款，100=已取消）")
    private String orderStatus;

    /**
     * 退款状态（0=正常，1=退款申请中，2=退款同意，3=退款拒绝，4=退款取消）
     */
    @Excel(name = "退款状态", readConverterExp = "0==正常，1=退款申请中，2=退款同意，3=退款拒绝，4=退款取消")
    @ApiModelProperty("退款状态（0=正常，1=退款申请中，2=退款同意，3=退款拒绝，4=退款取消）")
    private String refundStatus;

    /**
     * 退款申请时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @Excel(name = "退款申请时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("退款申请时间")
    private Date refundApplyTime;

    /**
     * 退款时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @Excel(name = "退款时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("退款时间")
    private Date refundTime;

    /**
     * 退款金额
     */
    @Excel(name = "退款金额")
    @ApiModelProperty("退款金额")
    private BigDecimal refundAmount;

    /**
     * 退款描述
     */
    @Excel(name = "退款描述")
    @ApiModelProperty("退款描述")
    private String refundContent;

    @ApiModelProperty("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date createTime;

    private ActivityCouponInfoVO activityCouponInfoVO;

    List<OrderActivityItem> orderActivityItemList;
}
