package com.yiqi.order.service;

import java.math.BigDecimal;
import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.order.domain.OrderPayInfo;

/**
 * 第三方支付记录Service接口
 *
 * @author douya
 * @date 2024-08-21
 */
public interface IOrderPayInfoService extends IService<OrderPayInfo> {

    //<editor-folder desc="基础函数">

    /**
     * 查询第三方支付记录
     *
     * @param id 第三方支付记录主键
     * @return 第三方支付记录
     */
    public OrderPayInfo selectOrderPayInfoById(Long id);

    /**
     * 查询第三方支付记录列表
     *
     * @param orderPayInfo 第三方支付记录
     * @return 第三方支付记录集合
     */
    public List<OrderPayInfo> selectOrderPayInfoList(OrderPayInfo orderPayInfo);

    /**
     * 新增第三方支付记录
     *
     * @param orderPayInfo 第三方支付记录
     * @return 结果
     */
    public int insertOrderPayInfo(OrderPayInfo orderPayInfo);

    /**
     * 修改第三方支付记录
     *
     * @param orderPayInfo 第三方支付记录
     * @return 结果
     */
    public int updateOrderPayInfo(OrderPayInfo orderPayInfo);

    /**
     * 批量删除第三方支付记录
     *
     * @param ids 需要删除的第三方支付记录主键集合
     * @return 结果
     */
    public int deleteOrderPayInfoByIds(Long[] ids);

    /**
     * 删除第三方支付记录信息
     *
     * @param id 第三方支付记录主键
     * @return 结果
     */
    public int deleteOrderPayInfoById(Long id);

    /**
     *  创建第三方支付记录
     * @param orderNo
     * @param payAmount
     * @param payType
     * @return
     */
    OrderPayInfo createOrderPayInfo(Long storeId, String orderNo, BigDecimal payAmount, String payType);

    /**
     * 根据支付订单号查询第三方支付记录
     * @param requestNo
     * @return
     */
    OrderPayInfo getOrderPayInfoByRequestNo(String requestNo);

    //</editor-folder>
}
