package com.yiqi.order.service;

import java.math.BigDecimal;
import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.order.domain.OrderPayInfo;
import com.yiqi.order.domain.OrderRefundInfo;
import com.yiqi.order.domain.dto.PayRefundDTO;

/**
 * 第三方退款记录Service接口
 *
 * @author douya
 * @date 2024-09-16
 */
public interface IOrderRefundInfoService extends IService<OrderRefundInfo> {

    //<editor-folder desc="基础函数">
    /**
     * 查询第三方退款记录
     *
     * @param id 第三方退款记录主键
     * @return 第三方退款记录
     */
    public OrderRefundInfo selectOrderRefundInfoById(Long id);

    /**
     * 查询第三方退款记录列表
     *
     * @param orderRefundInfo 第三方退款记录
     * @return 第三方退款记录集合
     */
    public List<OrderRefundInfo> selectOrderRefundInfoList(OrderRefundInfo orderRefundInfo);

    /**
     * 新增第三方退款记录
     *
     * @param orderRefundInfo 第三方退款记录
     * @return 结果
     */
    public int insertOrderRefundInfo(OrderRefundInfo orderRefundInfo);

    /**
     * 修改第三方退款记录
     *
     * @param orderRefundInfo 第三方退款记录
     * @return 结果
     */
    public int updateOrderRefundInfo(OrderRefundInfo orderRefundInfo);

    /**
     * 批量删除第三方退款记录
     *
     * @param ids 需要删除的第三方退款记录主键集合
     * @return 结果
     */
    public int deleteOrderRefundInfoByIds(Long[] ids);

    /**
     * 删除第三方退款记录信息
     *
     * @param id 第三方退款记录主键
     * @return 结果
     */
    public int deleteOrderRefundInfoById(Long id);


    /**
     *  创建第三方退款记录
     * @param payRefundDTO
     * @return
     */
    OrderRefundInfo createOrderRefundInfo(PayRefundDTO payRefundDTO);

    /**
     * 根据支付订单号查询第三方支付记录
     * @param requestNo
     * @return
     */
    OrderRefundInfo getOrderRefundInfoByRequestNo(String requestNo);
}
