package com.yiqi.activity.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.activity.domain.dto.ActivityAppCouponItemQueryDTO;
import com.yiqi.activity.domain.dto.ActivityCouponInfoDTO;
import com.yiqi.activity.domain.vo.ActivityAppCouponItemVO;
import com.yiqi.activity.domain.vo.ActivityCouponInfoVO;
import com.yiqi.app.domain.AppCouponType;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.activity.domain.ActivityCouponInfo;
import org.apache.ibatis.annotations.Param;

/**
 * 注册送券活动Mapper接口
 *
 * @author xiaohei
 * @date 2023-09-08
 */
@Mapper
public interface ActivityCouponInfoMapper extends BaseMapper<ActivityCouponInfo> {
    /**
     * 查询注册送券活动
     *
     * @param id 注册送券活动主键
     * @return 注册送券活动
     */
    public ActivityCouponInfoVO selectActivityCouponInfoById(Long id);

    /**
     * 查询活动优惠券信息，通过发放优惠劵
     *
     * @param activityId 活动主键
     * @return 注册送券活动
     */
    public ActivityCouponInfoVO selectActivityCouponInfoBySendCoupon(@Param("activityId") Long activityId,
                                                                     @Param("couponTypeId") Long couponTypeId);

    /**
     * 查询注册送券活动列表
     *
     * @param activityCouponInfoDTO 注册送券活动
     * @return 注册送券活动集合
     */
    public List<ActivityCouponInfoVO> selectActivityCouponInfoList(ActivityCouponInfoDTO activityCouponInfoDTO);

    /**
     * 新增注册送券活动
     *
     * @param activityCouponInfo 注册送券活动
     * @return 结果
     */
    public int insertActivityCouponInfo(ActivityCouponInfo activityCouponInfo);

    /**
     * 修改注册送券活动
     *
     * @param activityCouponInfo 注册送券活动
     * @return 结果
     */
    public int updateActivityCouponInfo(ActivityCouponInfo activityCouponInfo);

    /**
     * 删除注册送券活动
     *
     * @param id 注册送券活动主键
     * @return 结果
     */
    public int deleteActivityCouponInfoById(Long id);

    /**
     * 批量删除注册送券活动
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteActivityCouponInfoByIds(Long[] ids);

    List<AppCouponType> selectActivityCouponItemList(@Param("activityAppCouponItemQueryDTO") ActivityAppCouponItemQueryDTO activityAppCouponItemQueryDTO,
                                                     @Param("orgId") Long orgId,
                                                     @Param("sourceType") String sourceType);

    int countActivityCouponItemList(@Param("activityAppCouponItemQueryDTO") ActivityAppCouponItemQueryDTO activityAppCouponItemQueryDTO,
                                    @Param("orgId") Long orgId,
                                    @Param("sourceType") String sourceType);
}
