package com.yiqi.app.mapper;

import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.app.domain.dto.AppCouponItemQueryByAppUserIdDTO;
import com.yiqi.app.domain.dto.AppCouponItemQueryDTO;
import com.yiqi.app.domain.dto.MemberCouponItemQueryDTO;
import com.yiqi.app.domain.dto.weapp.AppCouponItemCountQueryDTO;
import com.yiqi.app.domain.vo.AppCouponItemVO;
import com.yiqi.system.domain.SysOrg;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.app.domain.AppCouponItem;
import org.apache.ibatis.annotations.Param;

/**
 * 优惠券Mapper接口
 *
 * @author xiaohei
 * @date 2023-09-19
 */
@Mapper
public interface AppCouponItemMapper extends BaseMapper<AppCouponItem> {

    public List<SysOrg> orgListByCouponId(@Param("couponItemId") Long couponItemId);

    public List<AppCouponItemVO> getlistByAppUserId(@Param("appCouponItemQueryByAppUserIdDTO") AppCouponItemQueryByAppUserIdDTO appCouponItemQueryByAppUserIdDTO
            , @Param("orgId") long orgId,@Param("sourceType") String sourceType);

    /**
     * 查询优惠券
     *
     * @param id 优惠券主键
     * @return 优惠券
     */
    public AppCouponItem selectAppCouponItemById(Long id);

    /**
     * 查询优惠券列表
     *
     * @param appCouponItemQueryDTO 优惠券
     * @return 优惠券集合
     */
    public List<AppCouponItemVO> selectAppCouponItemList(AppCouponItemQueryDTO appCouponItemQueryDTO);

    /**
     * 新增优惠券
     *
     * @param appCouponItem 优惠券
     * @return 结果
     */
    public int insertAppCouponItem(AppCouponItem appCouponItem);

    /**
     * 修改优惠券
     *
     * @param appCouponItem 优惠券
     * @return 结果
     */
    public int updateAppCouponItem(AppCouponItem appCouponItem);

    /**
     * 删除优惠券
     *
     * @param id 优惠券主键
     * @return 结果
     */
    public int deleteAppCouponItemById(Long id);

    /**
     * 批量删除优惠券
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppCouponItemByIds(Long[] ids);

    List<AppCouponItem> getMemberCouponInfoByRecharge(@Param("memberCouponItemQueryDTO") MemberCouponItemQueryDTO memberCouponItemQueryDTO,
                                                      @Param("NowDateTime") Date NowDateTime,
                                                      @Param("orgId") Long orgId,
                                                      @Param("sourceType") String sourceType);

    int  countMemberCouponInfoByRecharge(MemberCouponItemQueryDTO memberCouponItemQueryDTO, @Param("NowDateTime") Date NowDateTime);

    List<AppCouponItemVO> couponSendListByStore(AppCouponItemCountQueryDTO appCouponItemCountQueryDTO);

    int countCouponSendListByStore(AppCouponItemCountQueryDTO appCouponItemCountQueryDTO);

    int countTodaySendNumber(@Param("orgId") Long orgId,
                             @Param("sourceType") String sourceType,
                             @Param("dateTimeNow") String dateTimeNow);

    int countTodayHxNumber(@Param("orgId") Long orgId,
                           @Param("sourceType") String sourceType,
                           @Param("dateTimeNow") String dateTimeNow);
}
