package com.yiqi.app.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yiqi.app.domain.AppUser;
import com.yiqi.common.exception.GlobalException;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yiqi.app.mapper.AppOrgUserMapper;
import com.yiqi.app.domain.AppOrgUser;
import com.yiqi.app.service.IAppOrgUserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 组织客户关系管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-10-25
 */
@Service
public class AppOrgUserServiceImpl extends ServiceImpl<AppOrgUserMapper,AppOrgUser> implements IAppOrgUserService {

    /**
     * 查询组织客户关系管理
     *
     * @param id 组织客户关系管理主键
     * @return 组织客户关系管理
     */
    @Override
    public AppOrgUser selectAppOrgUserById(Long id) {
        return baseMapper.selectAppOrgUserById(id);
    }

    /**
     * 查询组织客户关系管理列表
     *
     * @param appOrgUser 组织客户关系管理
     * @return 组织客户关系管理
     */
    @Override
    public List<AppOrgUser> selectAppOrgUserList(AppOrgUser appOrgUser) {
        return baseMapper.selectAppOrgUserList(appOrgUser);
    }

    /**
     * 新增组织客户关系管理
     *
     * @param appOrgUser 组织客户关系管理
     * @return 结果
     */
    @Override
    public int insertAppOrgUser(AppOrgUser appOrgUser) {
        appOrgUser.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertAppOrgUser(appOrgUser);
    }

    /**
     * 修改组织客户关系管理
     *
     * @param appOrgUser 组织客户关系管理
     * @return 结果
     */
    @Override
    public int updateAppOrgUser(AppOrgUser appOrgUser) {
        appOrgUser.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateAppOrgUser(appOrgUser);
    }

    /**
     * 批量删除组织客户关系管理
     *
     * @param ids 需要删除的组织客户关系管理主键
     * @return 结果
     */
    @Override
    public int deleteAppOrgUserByIds(Long[] ids) {
        return baseMapper.deleteAppOrgUserByIds(ids);
    }

    /**
     * 删除组织客户关系管理信息
     *
     * @param id 组织客户关系管理主键
     * @return 结果
     */
    @Override
    public int deleteAppOrgUserById(Long id) {
        return baseMapper.deleteAppOrgUserById(id);
    }

    public void insertAppOrgUserByAppUser(AppUser user){
        long count = baseMapper.selectCount(new QueryWrapper<AppOrgUser>().lambda()
                .eq(AppOrgUser::getUserId, user.getId())
                .eq(AppOrgUser::getSourceType, SecurityUtils.getLoginUser().getSourceType())
                .eq(AppOrgUser::getOrgId, SecurityUtils.getLoginUser().getOrgId()));
        // 本店存在，不处理
        if (count>0){
            throw new GlobalException("客户已存在，无法创建");
        }

        AppOrgUser appOrgUser = new AppOrgUser();
        appOrgUser.setUserId(user.getId());
        appOrgUser.setOrgId(SecurityUtils.getLoginUser().getOrgId());
        appOrgUser.setSourceType(SecurityUtils.getLoginUser().getSourceType());
        appOrgUser.setCreateTime(DateUtils.getNowDate());
        appOrgUser.setCreateBy(SecurityUtils.getUsername());
        appOrgUser.setCreateById(SecurityUtils.getUserId());
        this.save(appOrgUser);
    }

}
