package com.yiqi.core.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.ClothItem;
import com.yiqi.core.domain.vo.ClothItemPriceVO;
import com.yiqi.core.domain.vo.ClothItemVo;
import com.yiqi.core.domain.vo.ClothItemWithPriceQueryVO;
import com.yiqi.core.domain.vo.ClothPriceVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 衣服Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-10
 */
@Mapper
public interface ClothItemMapper extends BaseMapper<ClothItem> {

    /**
     * 查询所有衣服（带默认洗衣方式价格）
     * @param clothTypeId 衣服类型ID
     * @return
     */
    public List<ClothItemWithPriceQueryVO> allWithPrice(@Param("clothTypeId") Long clothTypeId,@Param("bindAreaId")Long bindAreaId);

    /**
     * 查询衣服
     *
     * @param id 衣服主键
     * @return 衣服
     */
    public ClothItem selectClothItemById(Long id);

    public List<ClothItemPriceVO> selectClothItemPriceList(Long storeId);

    /**
     * 查询衣服列表
     *
     * @param clothItem 衣服
     * @return 衣服集合
     */
    public List<ClothItemVo> selectClothItemList(ClothItem clothItem);

    /**
     * 新增衣服
     *
     * @param clothItem 衣服
     * @return 结果
     */
    public int insertClothItem(ClothItem clothItem);

    /**
     * 修改衣服
     *
     * @param clothItem 衣服
     * @return 结果
     */
    public int updateClothItem(ClothItem clothItem);

    /**
     * 删除衣服
     *
     * @param id 衣服主键
     * @return 结果
     */
    public int deleteClothItemById(@Param("id") Long id, @Param("userId")Long userId, @Param("userName")String userName);

    /**
     * 批量删除衣服
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothItemByIds(@Param("ids")Long[] ids,@Param("userId")Long userId,@Param("userName")String userName);
}
