package com.yiqi.core.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.dto.GoodsSkuDTO;
import com.yiqi.core.domain.vo.GoodsSkuQueryVO;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.GoodsSku;
import org.apache.ibatis.annotations.Param;

/**
 * 物料明细Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-21
 */
@Mapper
public interface GoodsSkuMapper extends BaseMapper<GoodsSku> {
    /**
     * 查询物料明细
     *
     * @param id 物料明细主键
     * @return 物料明细
     */
    public GoodsSku selectGoodsSkuById(Long id);

    /**
     * 查询物料明细列表
     *
     * @param goodsSku 物料明细
     * @return 物料明细集合
     */
    public List<GoodsSku> selectGoodsSkuList(GoodsSku goodsSku);

    /**
     * 查询物料明细列表
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectGoodsSkuInfoByHq(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectGoodsSkuInfoByFactory(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectGoodsSkuInfoByStore(GoodsSkuDTO goodsSkuDTO);

    /**
     * 新增物料明细
     *
     * @param goodsSku 物料明细
     * @return 结果
     */
    public int insertGoodsSku(GoodsSku goodsSku);

    /**
     * 修改物料明细
     *
     * @param goodsSku 物料明细
     * @return 结果
     */
    public int updateGoodsSku(GoodsSku goodsSku);

    /**
     * 删除物料明细
     *
     * @param id 物料明细主键
     * @return 结果
     */
    public int deleteGoodsSkuById(Long id);

    /**
     * 批量删除物料明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGoodsSkuByIds(Long[] ids);


    /**
     * 查询物料明细列表  -总部查商品进货
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectPurchaseGoodsSkuInfoByHq(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表 -工厂查商品进货
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectPurchaseGoodsSkuInfoByFactory(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表 -门店查商品进货
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectPurchaseGoodsSkuInfoByStore(GoodsSkuDTO goodsSkuDTO);




    /**
     * 查询物料明细列表- 总部查零售
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectRetailGoodsSkuInfoByHq(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表  工厂查零售
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectRetailGoodsSkuInfoByFactory(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表  门店查零售
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectRetailGoodsSkuInfoByStore(GoodsSkuDTO goodsSkuDTO);


    /**
     * 查询商品sku数量
     *
     * @param goodsId 商品id
     * @return 结果
     */
    public Long getGoodsSkuNumsByGoodsId(@Param("goodsId") Long goodsId);
}
