package com.yiqi.core.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yiqi.common.exception.GlobalException;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import com.yiqi.core.domain.GoodsCategory;
import com.yiqi.core.mapper.GoodsCategoryMapper;
import com.yiqi.core.service.IGoodsCategoryService;
import com.yiqi.core.service.IGoodsInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

/**
 * 商品类型管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-08-21
 */
@Service
public class GoodsCategoryServiceImpl extends ServiceImpl<GoodsCategoryMapper, GoodsCategory> implements IGoodsCategoryService {

    @Autowired
    IGoodsInfoService goodsInfoService;

    /**
     * 查询商品类型管理
     *
     * @param id 商品类型管理主键
     * @return 商品类型管理
     */
    @Override
    public GoodsCategory selectGoodsCategoryById(Long id) {
        return baseMapper.selectGoodsCategoryById(id);
    }

    /**
     * 查询商品类型管理列表
     *
     * @param goodsCategory 商品类型管理
     * @return 商品类型管理
     */
    @Override
    public List<GoodsCategory> selectGoodsCategoryList(GoodsCategory goodsCategory) {
        return baseMapper.selectGoodsCategoryList(goodsCategory);
    }

    /**
     * 新增商品类型管理
     *
     * @param goodsCategory 商品类型管理
     * @return 结果
     */
    @Override
    public int insertGoodsCategory(GoodsCategory goodsCategory) {
        goodsCategory.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertGoodsCategory(goodsCategory);
    }

    /**
     * 修改商品类型管理
     *
     * @param goodsCategory 商品类型管理
     * @return 结果
     */
    @Override
    public int updateGoodsCategory(GoodsCategory goodsCategory) {
        goodsCategory.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateGoodsCategory(goodsCategory);
    }

    /**
     * 批量删除商品类型管理
     *
     * @param ids 需要删除的商品类型管理主键
     * @return 结果
     */
    @Override
    public int deleteGoodsCategoryByIds(Long[] ids) {
        int count = goodsInfoService.selectGoodsCategoryIds(ids);
        if (count > 0){
            throw new GlobalException("存在该类型的商品,无法删除");
        }
        return baseMapper.deleteGoodsCategoryByIds(ids);
    }

    /**
     * 删除商品类型管理信息
     *
     * @param id 商品类型管理主键
     * @return 结果
     */
    @Override
    public int deleteGoodsCategoryById(Long id) {
        return baseMapper.deleteGoodsCategoryById(id);
    }


    /**
     * 修改商品类型管理状态
     *
     * @param goodsCategory 商品类型
     * @return 结果
     */
    @Override
    public int updateCategoryStatus(GoodsCategory goodsCategory) {
        goodsCategory.setUpdateBy(SecurityUtils.getUsername());
        goodsCategory.setUpdateById(SecurityUtils.getUserId());
        goodsCategory.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateGoodsCategory(goodsCategory);
    }
}
