package com.yiqi.core.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import com.yiqi.core.domain.GoodsStore;
import com.yiqi.core.mapper.GoodsStoreMapper;
import com.yiqi.core.service.IGoodsStoreService;
import com.yiqi.system.domain.ManageFactory;
import com.yiqi.system.domain.SysStore;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 商品门店Service业务层处理
 *
 * @author ruoyi
 * @date 2023-08-21
 */
@Service
public class GoodsStoreServiceImpl extends ServiceImpl<GoodsStoreMapper, GoodsStore> implements IGoodsStoreService {

    /**
     * 查询商品门店
     *
     * @param id 商品门店主键
     * @return 商品门店
     */
    @Override
    public GoodsStore selectGoodsStoreById(Long id) {
        return baseMapper.selectGoodsStoreById(id);
    }

    /**
     * 查询商品门店列表
     *
     * @param goodsStore 商品门店
     * @return 商品门店
     */
    @Override
    public List<GoodsStore> selectGoodsStoreList(GoodsStore goodsStore) {
        return baseMapper.selectGoodsStoreList(goodsStore);
    }

    /**
     * 新增商品门店
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    @Override
    public int insertGoodsStore(GoodsStore goodsStore) {
        goodsStore.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertGoodsStore(goodsStore);
    }

    /**
     * 修改商品门店
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    @Override
    public int updateGoodsStore(GoodsStore goodsStore) {
        goodsStore.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateGoodsStore(goodsStore);
    }

    /**
     * 批量删除商品门店
     *
     * @param ids 需要删除的商品门店主键
     * @return 结果
     */
    @Override
    public int deleteGoodsStoreByIds(Long[] ids) {
        return baseMapper.deleteGoodsStoreByIds(ids);
    }

    /**
     * 删除商品门店信息
     *
     * @param id 商品门店主键
     * @return 结果
     */
    @Override
    public int deleteGoodsStoreById(Long id) {
        return baseMapper.deleteGoodsStoreById(id);
    }

    /**
     * 修改商品门店状态
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    @Override
    public int updateGoodsStoreStatus(GoodsStore goodsStore) {
        goodsStore.setUpdateBy(SecurityUtils.getUsername());
        goodsStore.setUpdateById(SecurityUtils.getUserId());
        goodsStore.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateGoodsStore(goodsStore);
    }

    @Override
    public int insertGoodsToAllFactory(GoodsStore goodsStore) {
        return baseMapper.insertGoodsToAllFactory(goodsStore);
    }

    @Override
    public int insertGoodsToAllStore(GoodsStore goodsStore) {
        return baseMapper.insertGoodsToAllStore(goodsStore);
    }

    @Override
    public int insertFactoryToAllGoods(ManageFactory manageFactory) {
        return baseMapper.insertFactoryToAllGoods(manageFactory);
    }

    @Override
    public int insertStoreToAllGoods(SysStore sysStore) {
        return baseMapper.insertStoreToAllGoods(sysStore);
    }


}
