package com.yiqi.order.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.order.domain.OrderRecharge;
import com.yiqi.order.domain.OrderRechargeInstalment;
import com.yiqi.order.domain.dto.OrderFinancialDayQueryDTO;
import com.yiqi.order.domain.dto.OrderRechargeCreateDTO;
import com.yiqi.order.domain.dto.OrderRechargeQueryDTO;
import com.yiqi.order.domain.dto.OrderRechargeRefundQueryDTO;
import com.yiqi.order.domain.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 充值订单Mapper接口
 *
 * @author ruoyi
 * @date 2023-09-27
 */
@Mapper
public interface OrderRechargeMapper extends BaseMapper<OrderRecharge> {
    /**
     * 查询充值订单
     *
     * @param id 充值订单主键
     * @return 充值订单
     */
    public OrderRecharge selectOrderRechargeById(Long id);

    /**
     * 查询充值订单列表
     *
     * @param orderRechargeQueryDTO 充值订单
     * @return 充值订单集合
     */
    public List<OrderRechargeListVO> selectOrderRechargeList(OrderRechargeQueryDTO orderRechargeQueryDTO);

    /**
     * 充值订单列表-撤单退款
     *
     * @param orderRechargeRefundQueryDTO 充值订单退款查询对象
     * @return 充值订单集合
     */
    public List<OrderRechargeRefundListVO> refundRechargeOrderList(OrderRechargeRefundQueryDTO orderRechargeRefundQueryDTO);


    /**
     * 查询退卡列表
     *
     * @param orderRechargeListVO 退卡
     * @return 充值订单集合
     */
    public List<OrderRechargeListVO> selectRefundList(OrderRechargeListVO orderRechargeListVO);
    /**
     * 新增充值订单
     *
     * @param orderRecharge 充值订单
     * @return 结果
     */
    public int insertOrderRecharge(OrderRecharge orderRecharge);

    /**
     * 修改充值订单
     *
     * @param orderRecharge 充值订单
     * @return 结果
     */
    public int updateOrderRecharge(OrderRecharge orderRecharge);

    /**
     * 删除充值订单
     *
     * @param id 充值订单主键
     * @return 结果
     */
    public int deleteOrderRechargeById(Long id);

    /**
     * 批量删除充值订单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderRechargeByIds(Long[] ids);


    public void updatePayAmount(OrderRechargeCreateDTO orderRechargeCreateDTO);

    /**
     * 查询支付详情明细
     *
     * @param orderId 充值订单主键
     * @return 查询支付详情明细
     */
    public List<OrderRechargeInstalment> getPayDetailById (@Param("orderId") Long orderId, @Param("orderStatus") String orderStatus);


    /**
     * 查询门店会员充值记录
     *
     * @param useId 客户id
     * @return 查询门店会员充值记录
     */
    public List<OrderRechargeRecordVO> getRechargeRecordByUserId (Long useId);

    public List<OrderRechargeFinancialVO> listFinancialStatisticsByRechargeOrderToday(@Param("orderFinancialDayQueryDTO") OrderFinancialDayQueryDTO orderFinancialDayQueryDTO,
                                                                                      @Param("orgId") Long orgId,
                                                                                      @Param("sourceType") String sourceType);

    public List<OrderRechargeFinancialVO> listFinancialStatisticsByRechargeOrderMTD(@Param("orgId") Long orgId, @Param("sourceType") String sourceType);
}
