package com.yiqi.recharge.service.impl;

import java.util.List;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yiqi.recharge.mapper.RechargeCardVersionMapper;
import com.yiqi.recharge.domain.RechargeCardVersion;
import com.yiqi.recharge.service.IRechargeCardVersionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 充值卡版本Service业务层处理
 *
 * @author 小黑
 * @date 2023-08-29
 */
@Service
public class RechargeCardVersionServiceImpl extends ServiceImpl<RechargeCardVersionMapper,RechargeCardVersion> implements IRechargeCardVersionService {

    /**
     * 查询充值卡版本
     *
     * @param id 充值卡版本主键
     * @return 充值卡版本
     */
    @Override
    public RechargeCardVersion selectRechargeCardVersionById(Long id) {
        return baseMapper.selectRechargeCardVersionById(id);
    }

    /**
     * 查询充值卡版本列表
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 充值卡版本
     */
    @Override
    public List<RechargeCardVersion> selectRechargeCardVersionList(RechargeCardVersion rechargeCardVersion) {
        return baseMapper.selectRechargeCardVersionList(rechargeCardVersion);
    }

    /**
     * 新增充值卡版本
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 结果
     */
    @Override
    public int insertRechargeCardVersion(RechargeCardVersion rechargeCardVersion) {
        rechargeCardVersion.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertRechargeCardVersion(rechargeCardVersion);
    }

    /**
     * 修改充值卡版本
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 结果
     */
    @Override
    public int updateRechargeCardVersion(RechargeCardVersion rechargeCardVersion) {
        rechargeCardVersion.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateRechargeCardVersion(rechargeCardVersion);
    }

    /**
     * 批量删除充值卡版本
     *
     * @param ids 需要删除的充值卡版本主键
     * @return 结果
     */
    @Override
    public int deleteRechargeCardVersionByIds(Long[] ids) {
        return baseMapper.deleteRechargeCardVersionByIds(ids);
    }

    /**
     * 删除充值卡版本信息
     *
     * @param id 充值卡版本主键
     * @return 结果
     */
    @Override
    public int deleteRechargeCardVersionById(Long id) {
        return baseMapper.deleteRechargeCardVersionById(id);
    }

    /**
     * 修改充值卡版本状态
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 结果
     */
    @Override
    public int updateRechargeCardVersionStatus(RechargeCardVersion rechargeCardVersion) {
        rechargeCardVersion.setUpdateById(SecurityUtils.getUserId());
        rechargeCardVersion.setUpdateBy(SecurityUtils.getUsername());
        rechargeCardVersion.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateRechargeCardVersion(rechargeCardVersion);
    }


}
