package com.yiqi.system.service.impl;

import java.util.List;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yiqi.system.mapper.SysDocumentMapper;
import com.yiqi.system.domain.SysDocument;
import com.yiqi.system.service.ISysDocumentService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 系统文档Service业务层处理
 *
 * @author xiaohei
 * @date 2023-09-01
 */
@Service
public class SysDocumentServiceImpl extends ServiceImpl<SysDocumentMapper,SysDocument> implements ISysDocumentService {

    /**
     * 查询系统文档
     *
     * @param id 系统文档主键
     * @return 系统文档
     */
    @Override
    public SysDocument selectSysDocumentById(Long id) {
        return baseMapper.selectSysDocumentById(id);
    }

    /**
     * 查询系统文档列表
     *
     * @param sysDocument 系统文档
     * @return 系统文档
     */
    @Override
    public List<SysDocument> selectSysDocumentList(SysDocument sysDocument) {
        return baseMapper.selectSysDocumentList(sysDocument);
    }

    /**
     * 新增系统文档
     *
     * @param sysDocument 系统文档
     * @return 结果
     */
    @Override
    public int insertSysDocument(SysDocument sysDocument) {
        sysDocument.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertSysDocument(sysDocument);
    }

    /**
     * 修改系统文档
     *
     * @param sysDocument 系统文档
     * @return 结果
     */
    @Override
    public int updateSysDocument(SysDocument sysDocument) {
        sysDocument.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateSysDocument(sysDocument);
    }

    /**
     * 批量删除系统文档
     *
     * @param ids 需要删除的系统文档主键
     * @return 结果
     */
    @Override
    public int deleteSysDocumentByIds(Long[] ids) {
        return baseMapper.deleteSysDocumentByIds(ids);
    }

    /**
     * 删除系统文档信息
     *
     * @param id 系统文档主键
     * @return 结果
     */
    @Override
    public int deleteSysDocumentById(Long id) {
        return baseMapper.deleteSysDocumentById(id);
    }



}
